@@ -238,6 +238,12 @@ class BaseExperiment:
     )->Union["pl.LightningModule", "BaseEstimator"]:
         r"""Method for setting a model.
 
+        When calling set_model(), you should specify the class of the model (model_type)e.g., MLP, LitModel as an input argument together with their 
+        configurations(**hparams).
+
+        Then, the model would be created and its 'metadata' a string describing the model will also be created.
+        Note that the model will be saved in .stack after being trained.  
+
         Args:
 
             model_type (`LightningModule` or `BaseEstimator`): The type of model. (class)
@@ -247,6 +253,49 @@ class BaseExperiment:
         Returns:
 
             :obj:LightningModule or :obj:BaseEstimator: self.model
+
+        Note: 
+
+            You can also set models of sklearn-based models such as xgboost.XGBClassifier or other custom
+            LightningModules you made. See Example.
+
+            When passing a custom LightningModule, you MUST make the module to log metrics.
+            The format of metrics are : 'train/acc', 'val/loss', 'val/auc', 'val/acc', 'test/acc', etc.
+            
+        Example::
+
+            >>> class LitModel(pl.LightningModule):
+                    def __init__(self):
+                        super().__init__()
+                        self.l1 = nn.Linear(8 * 8, 10)
+
+                    def forward(self, x):
+                        return torch.relu(self.l1(x.view(x.size(0), -1)))
+
+                    def training_step(self, batch, batch_idx):
+                        x, y = batch
+                        y_hat = self(x)
+                        loss, acc, auc = CELossMetrics(10)(y_hat=y_hat, labels=y)
+                        self.log('train/loss',loss) # MUST DO
+                        self.log('train/acc',acc) # MUST DO
+                        self.log('train/auc',auc) # MUST DO
+                        return loss
+
+                    def validation_step(self, val_batch, batch_idx):
+                        x, y = val_batch
+                        y_hat = self(x)
+                    
+                        loss, acc, auc = CELossMetrics(10)(y_hat=y_hat, labels=y)
+
+                        self.log('val/loss', loss) # MUST DO
+                        self.log('val/acc', acc) # MUST DO
+                        self.log('val/auc', auc) # MUST DO
+                        return {'loss' : loss, 'acc' : acc, 'auc' : auc}
+
+                    def configure_optimizers(self):
+                        return torch.optim.Adam(self.parameters(), lr=0.02)
+
+            >>> exp.set_model(LitModel)
         """
         if BaseNet in inspect.getmro(model_type) or ConvNet in inspect.getmro(model_type): # astrape models
             self.model = model_type(dims=self.dims, n_classes=self.n_classes, **hparams)
