@@ -17,11 +17,11 @@ import warnings
 warnings.filterwarnings(action='ignore')
 
 class Experiment(BaseExperiment):
-    r"""Experiment class.
+    r"""``Experiment`` class.
 
     Note:
-        This class is just BaseExperiment with cross_validation.
-        See astrape.base.experiment_base for details.
+        This class is just ``BaseExperiment`` with ``cross_validation``.
+        See ``astrape.base.experiment_base`` for details.
     """
     def __init__(
         self,
