@@ -31,7 +31,7 @@ available_domain_types = ["points", "image", "audio"]
 
 
 class BaseProject:
-    r"""Parent class of `Project` class. 
+    r"""Parent class of ``Project`` class. 
     
     Methods will perform 1)plotting data, 2)generating ``Experiments``,
     3)setting models across the generated `Experiment`s, 4)setting trainers across the generated ``Experiments``,
@@ -236,7 +236,7 @@ class BaseProject:
 
         Args:
 
-            experiment (:obj:`Experiment`): Experiment you want to add.
+            experiment (:obj:``Experiment``): ``Experiment`` you want to add.
 
         Returns:
 
@@ -260,11 +260,11 @@ class BaseProject:
 
         Args:
 
-            model_type (`LightningModule` or `BaseEstimator`): Class of the model you want to use.
+            model_type (``LightningModule`` or ``BaseEstimator``): Class of the model you want to use.
 
             **hparams (Any): Hyperparameters for the model. 
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to set model to. If None, will set models for all ``Experiments`` in ``exps``.
+            random_states (:obj:``list`` of `int`, optional): The list of random states of ``Experiments`` you want to set model to. If None, will set models for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -298,7 +298,7 @@ class BaseProject:
 
             **trainer_config (Any): Trainer configurations.
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to set trainer to. If None, will set trainers for all ``Experiments`` in ``exps``.
+            random_states (:obj:``list`` of `int`, optional): The list of random states of ``Experiments`` you want to set trainer to. If None, will set trainers for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -332,7 +332,7 @@ class BaseProject:
 
             **trainer_config (Any): Trainer configurations.
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to fit. If None, will fit all ``Experiments`` in ``exps``.
+            random_states (:obj:``list`` of `int`, optional): The list of random states of ``Experiments`` you want to fit. If None, will fit all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -363,7 +363,7 @@ class BaseProject:
 
         Args:
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to save checkpoint. If None, will save checkpoint for all ``Experiments`` in ``exps``.
+            random_states (:obj:``list`` of `int`, optional): The list of random states of ``Experiments`` you want to save checkpoint. If None, will save checkpoint for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
@@ -389,11 +389,11 @@ class BaseProject:
         self,
         random_states : Optional[List[int]] = None, # if None, all experiments will save stacks
     )->None:
-        r"""Apply `save_stack` for ``Experiments`` in ``exps``.
+        r"""Apply ``save_stack()`` for ``Experiments`` in ``exps``.
 
         Args:
 
-            random_states (:obj:`list` of `int`, optional): The list of random states of ``Experiments`` you want to save stack. If None, will save stack for all ``Experiments`` in ``exps``.
+            random_states (:obj:``list`` of `int`, optional): The list of random states of ``Experiments`` you want to save stack. If None, will save stack for all ``Experiments`` in ``exps``.
                 Default: ``None``
 
         Returns:
